@@ -34,7 +34,12 @@ impl<'c> JsonCodec for SqliteValueRef<'c> {
             }
             "BLOB" => {
                 let r: Option<Vec<u8>> = Decode::<'_, Sqlite>::decode(self)?;
-                return Ok(new_json_option_into!(r));
+                if let Some(r)= r{
+                    return Ok(serde_json::json!(crate::types::byte::RbBytes{
+                        rb_bytes:r,
+                    }));
+                }
+                return Ok(serde_json::Value::Null);
             }
             _ => {
                 //TODO "NUMERIC" |"DATE" | "TIME" | "DATETIME"
