@@ -32,10 +32,11 @@ impl<'de> serde::Deserialize<'de> for RbJson {
         if js.is_object() {
             if let Some(obj) = js.as_object_mut() {
                 if obj.len() == 1 {
-                    let v = obj.remove("rb_json").unwrap();
-                    return Ok(RbJson {
-                        rb_json: v,
-                    });
+                    if let Some(v) = obj.remove("rb_json") {
+                        return Ok(RbJson {
+                            rb_json: v,
+                        });
+                    }
                 }
             }
         }
